@@ -205,6 +205,13 @@ class InteractiveParameterFinder:
             print(msg)
             d += 1
             self.box_diameter.set_val(str(d))
+        if d <= 1:
+            msg = (f"You set diameter to {d}, but "
+                   "diameter needs to be uneven and greater than 2. "
+                   "Will set it to 3 now.")
+            print(msg)
+            d = 3
+            self.box_diameter.set_val(str(d))
         self.parameters.diameter = d
         self.update()
 
@@ -218,11 +225,12 @@ class InteractiveParameterFinder:
         self.axhist.clear()
         features = tp.locate(frame, self.parameters.diameter,
                              minmass=self.parameters.mass)
+        
         tp.annotate(features, frame, invert=False, ax=self.aximg,
                     imshow_style={'origin': 'lower'})
         self.axhist.hist(features['mass'], bins=20)
         self.fig.canvas.draw()
-
+        
 
 def load_frames(file_pattern: str) -> Tuple[List[str], Frames]:
     files = sorted(glob.glob(file_pattern))
@@ -258,4 +266,4 @@ def _is_video(fname: str) -> bool:
     extension = os.path.splitext(fname)[1]
     if extension.lower() in allowed_extensions:
         return True
-    return False
\ No newline at end of file
+    return False
